Pressure Modules (``taurex.pressure``)
======================================

Base
----------------------------------------------------

.. autoclass:: taurex.data.profiles.pressure.pressureprofile.PressureProfile
   :members:
   :undoc-members:
   :show-inheritance:

Simple
----------------------------------------------------

.. autoclass:: taurex.data.profiles.pressure.pressureprofile.SimplePressureProfile
   :members:
   :undoc-members:
   :show-inheritance:

